from django.db import models

"""
	@name: OAthToken
	@author: exile.sas
	@date: 27/06/2016
	@licence: creative commons
"""
class OAuthToken(models.Model):
	date = models.DateTimeField(auto_now_add=True)
	token = models.CharField(max_length=120)

# end class





"""
	@name: SupraOAth
	@author: exile.sas
	@date: 27/06/2016
	@licence: creative commons
"""
class SupraOAth(object):
	def __call__(self, request):
		from models import OAthToken
		if 'HTTP_AUTHORIZATION' in request.META:
			token = request.META['HTTP_AUTHORIZATION']
			token = OAthToken.objects.filter(token=token).first()
			if token:
				return None
			# end if
		# end if
		from django.core.exceptions import PermissionDenied
		raise PermissionDenied
	# end def
# end def



from django.core.exceptions import PermissionDenied
from django.core.urlresolvers import Resolver404


"""
	@name: SupraAuthenticationMixin
	@author: exile.sas
	@date: 27/06/2016
	@licence: creative commons
"""
class SupraAuthenticationMixin(object):
	auths = []

	def auth(self, request, *args, **kwargs):
		for auth in self.auths:
			au = auth()(request)
			if au:
				return au
			# end if
		# end for
	# end def

	@classmethod
	def append(cls, method):
		cls.auths.append(method)
	# end def

# end class

methods = SupraAuthenticationMixin


from django import template
import json
register = template.Library()


@register.filter
def get_type(value):
	return type(value).__name__
#end def

@register.filter
def strip(dic):
	stri = json.dumps(dic)
	if len(stri) > 53:
		stri = stri[:50] + "..."
	#end if
	return stri
#end def


import tornado.ioloop
import tornado.web
import tornado.websocket

from tornado.options import define, options, parse_command_line

define("port", default=8888, help="run on the given port", type=int)

# we gonna store clients in dictionary.
clients = dict()

class WebSocketHandler(tornado.websocket.WebSocketHandler):
    def open(self, *args):
        self.id = self.get_argument("Id")
        self.stream.set_nodelay(True)
        clients[self.id] = {"id": self.id, "object": self}
    #end def

    def check_origin(self, origin):
        return True

    def on_message(self, message):
        msg = "Client %s received a message : %s" % (self.id, message)
        self.write_message(msg)
        print msg
    #end def
        
    def on_close(self):
        if self.id in clients:
            del clients[self.id]
        #end if
    #end def
#end class

app = tornado.web.Application([
    (r'/', WebSocketHandler),
])

if __name__ == '__main__':
    parse_command_line()
    app.listen(options.port)
    tornado.ioloop.IOLoop.instance().start()